@@ -30,7 +30,7 @@
             psi <- 2 * lambda
         }else if(lambda < 0){           # Student-t
             psi <- 0
-            chi <- 2 * (-lambda - 1)
+            chi <- -2 * (lambda + 1)
         }else{
             stop("Forbidden combination of parameter values");
         }
@@ -198,11 +198,11 @@
     default.names <- c("lambda", "alpha.bar", "mu", "sigma", "gamma")
     ## There are 3 possibilities:
     ## (1) opt.pars are not named: They must be of length 5
-    ##     and in the order of 'default.names'
+    ##     and are interpreted in the same order as 'default.names'
     ## (2) opt.pars are named and are in 'default.names':
     ##     (*) Any unknown names are dropped
     ##     (*) opt.pars is reordered
-    ## (3) If unknown opt.pars are passed an error occurs
+    ## (3) If opt.pars with unknown names are passed an error occurs
     if(is.null(names(opt.pars))){
         if(length(opt.pars) == 5){
             new.opt.pars <- c(lambda = opt.pars[1], alpha.bar = opt.pars[2],
@@ -210,14 +210,22 @@
                               gamma = opt.pars[5])
 
             if(new.opt.pars["gamma"] & symmetric){
-                warning("'symmetric' and opt.pars[5] are TRUE!\n",
-                        "opt.pars[5] is set to FALSE!\n")
+                warning("Clash: symmetric == TRUE while opt.pars[5] == TRUE!\n",
+                        "A symmetric model will be fitted (i.e. opt.pars[5] <- FALSE)!\n")
             }
         }else{
-            stop("If opt.pars is not named it must have length 5!\n",
+            stop("If 'opt.pars' is not named it must have length 5!\n",
                  "The order is lambda, alpha.bar, mu, sigma, gamma.\n")
         }
     }else{
+        ## In case a named argument 'symmetric' was submitted and
+        ## 'opt.pars' was not submited, the name corresponding to the
+        ## 'gamma' parameter in 'opt.pars' is of the structure
+        ## 'gamma.xx'. Here, set it back to 'gamma'.
+        if(length(grep("gamma", names(opt.pars))) > 0){
+            names(opt.pars)[grep("gamma", names(opt.pars))] <- "gamma"
+        }
+
         if(all(default.names %in% names(opt.pars))){
             if(length(opt.pars) != 5){
                 warning("The following names were dropped:\n",
@@ -230,8 +238,8 @@
                               sigma = unname(opt.pars["sigma"]),
                               gamma = unname(opt.pars["gamma"]))
             if(new.opt.pars["gamma"] & symmetric){
-                warning("'symmetric' and opt.pars['gamma'] are TRUE!\n",
-                        "opt.pars['gamma'] is set to FALSE!\n")
+                warning("Clash: symmetric == TRUE while opt.pars['gamma'] == TRUE!\n",
+                        "A symmetric model will be fitted (i.e. opt.pars['gamma'] <- FALSE)!\n")
             }
         }else if(!any(default.names %in% names(opt.pars))){
             stop("The names '", paste(names(opt.pars), collapse = "', '"),
@@ -265,8 +273,8 @@
             if("gamma" %in% names(opt.pars)){
                 new.opt.pars <-  c(new.opt.pars, gamma = unname(opt.pars["gamma"]))
                 if(new.opt.pars["gamma"] & symmetric){
-                    warning("'symmetric' and opt.pars['gamma'] are TRUE!\n",
-                            "opt.pars['gamma'] is set to FALSE!\n")
+                warning("Clash: symmetric == TRUE while opt.pars['gamma'] == TRUE!\n",
+                        "A symmetric model will be fitted (i.e. opt.pars['gamma'] <- FALSE)!\n")
                 }
             }else{
                 new.opt.pars <-  c(new.opt.pars, gamma = TRUE)
@@ -401,9 +409,6 @@
 ".dghypuv" <- function(x, lambda = 1, chi = 1, psi = 1, alpha.bar = NULL,
                              mu = 1, sigma = 1, gamma = 0, logvalue = FALSE)
 {
-    ## Density of a univariate generalized hyperbolic distribution.
-    ## Covers all special cases as well.
-
     sigma <- as.vector(sigma)
     if(!is.null(alpha.bar)){
         tmp.abar2chipsi <- .abar2chipsi(alpha.bar, lambda)
@@ -426,13 +431,21 @@
     }
     out <- NA
     if (psi == 0){
+        lambda.min.0.5 <- lambda - 0.5
         if(symm){                       # Symmetric Student-t
-            nu <- -2 * lambda
-            sigma.t <- sqrt((nu - 2) / nu) * sigma
-            out <- dt((x - mu) / sigma.t, df = nu, log = TRUE) - log(sigma.t)
+##             nu <- -2 * lambda
+##             sigma.t <- sqrt((nu - 2) / nu) * sigma
+##             out <- dt((x - mu) / sigma.t, df = nu, log = TRUE) - log(sigma.t)
+
+            interm <- chi + Q
+
+            log.const.top <- -lambda * log(chi) + lgamma(-lambda.min.0.5)
+            log.const.bottom <- 0.5 * log(pi) + log(sigma) + lgamma(-lambda)
+            log.top <- lambda.min.0.5 * log(interm)
+
+            out <- log.const.top + log.top - log.const.bottom
         }else{                          # Asymmetric Student-t
             interm <- sqrt((chi + Q) * skewness.norm)
-            lambda.min.0.5 <- lambda - 0.5
 
             log.const.top <- -lambda * log(chi) - lambda.min.0.5 * log(skewness.norm)
             log.const.bottom <- 0.5 * log(2 * pi) + log(sigma) + lgamma(-lambda) - (lambda + 1) * log(2)
